import { select, 
        json,
        csv,
        tsv, 
        geoPath,
        geoMercator,
        scaleOrdinal,
        schemeCategory10,
        zoom,
        event } from 'd3';
import { feature } from 'topojson';

//selecting the svg area where chart will be plotted
const svg = select('svg');
const width = parseFloat(svg.attr('width'));
const height = +svg.attr('height');
let stateNames = [];

//defining the charts projection with d3.js geoMercator() function
const projection = geoMercator()
			.clipExtent([[0,0],[width,height]])
			.center([78.9, 20.6])
			.scale(770);

//defining the path with d3.js geoPath() function
const pathGenerator = geoPath()
		.projection(projection);

const g = svg.append('g');

// rendering topographic layer of the map
svg.call(zoom().on('zoom', () => {
	g.attr('transform', event.transform)
}));


Promise.all([json('https://gist.githubusercontent.com/avadhanuladheeraj/84ca4c817cf65d931df6c60e01a1bf3a/raw/ba6113cfbe44480085a8a6cbccb8fa039721974b/india.json')
            ]).then(([stateJSON]) => {
	 
  const stateGroup = g.append('g');
  		
  const states = feature(stateJSON, stateJSON.objects.IND_adm1);
  
 	const colorScale = scaleOrdinal(schemeCategory10);

  const statePath = stateGroup.selectAll('path')
    .data(states.features)
  statePath.enter().append('path')
    .attr('class', 'states')
    .attr('d', d => pathGenerator(d))
});
      